pub struct Entry<'a, 'rem, T> { /* private fields */ }Expand description
Vec entry.
Entry allows you to remove, read or mutate the element
behind it.
The only way to get this struct is to call Removing::next method.
forget behavior
When Entry destructor (drop) is not runned (this can be achieved via
mem::forget, ManuallyDrop, etc) the entry is not skiped and the next
call to Removing::next returns the same entry.
use core::mem;
use vecrem::VecExt;
let mut vec = vec![1, 2, 3];
{
let mut rem = vec.removing();
let a = rem.next().unwrap();
assert_eq!(a.value(), &1);
mem::forget(a);
let b = rem.next().unwrap();
assert_eq!(b.value(), &1);
mem::forget(b);
}
assert_eq!(vec, [1, 2, 3]);Implementations